import random

alphabet = {

    'a': '1134', 
    'b': '2341', 
    'c': '1514', 
    'd': '74234', 
    'e': '2346', 
    'f': '8726', 
    'g': '8934', 
    'h': '3119', 
    'i': '2574', 
    'j': '9344', 
    'k': '1234', 
    'l': '8901', 
    'm': '6713', 
    'n': '7892', 
    'o': '2372', 
    'p': '6438', 
    'q': '2364', 
    'r': '1927', 
    's': '3478', 
    't': '2830', 
    'u': '7364', 
    'v': '9873', 
    'w': '2034', 
    'x': '6712', 
    'y': '6183', 
    'z': '1264', 
    '-': '8193',
    '_': '1297', 
    '.': '2739', 
    ',': '2983',
}


alphabet1 = {

    1134.0: 'a', 
    2341.0: 'b', 
    1514.0: 'c', 
    74234.0: 'd', 
    2346.0: 'e', 
    8726.0: 'f', 
    8934.0: 'g', 
    3119.0: 'h', 
    2574.0: 'i', 
    9344.0: 'j', 
    1234.0: 'k', 
    8901.0: 'l', 
    6713.0: 'm', 
    7892.0: 'n', 
    2372.0: 'o', 
    6438.0: 'p', 
    2364.0: 'q', 
    1927.0: 'r', 
    3478.0: 's', 
    2830.0: 't', 
    7364.0: 'u', 
    9873.0: 'v', 
    2034.0: 'w', 
    6712.0: 'x', 
    6183.0: 'y', 
    1264.0: 'z', 
    8193.0: '-', 
    2739.0: '.',
    2983.0: ','
}


class Shifr:

    def __init__(self):
        self.key = []
        self.message = []
        self.encryption_message = []
        self.long_message = 0


    def key_gen(self):
        for self.i in self.message:
            self.long_message += 1

        for self.i in range(self.long_message):
            self.rand = random.randint(10, 101)
            self.key.append(self.rand)

        return(self.key)


    def  create_message(self, message):
        message.lower()
        for i in message:
            k = alphabet.get(i)
            self.message.append(k)


    def encryption(self):
        for self.i in range(len(self.message)):

            self.one_encryption_message = int(self.message[self.i]) * self.key[self.i]
            self.encryption_message.append(int(self.one_encryption_message))

        return self.encryption_message



class DeShifr:

    def __init__(self):
        self.decryption_message = []
        self.finally_message = []

    def decryption(self, keys, message):
        for self.i in range(len(message)):
            self.one_decryption_message = int(message[self.i]) / int(keys[self.i])
            self.decryption_message.append(self.one_decryption_message)


    def message_formation(self):
        for self.i in self.decryption_message:
            self.k = alphabet1.get(self.i)
            self.finally_message.append(self.k)

        return self.finally_message


'''   
EXAMPLE: 

a = Shifr()
a.create_message("hello")   # create_message
print(a.key_gen())      # create_keys
print(a.encryption())   # print encryption message

# -------------------------------------------------------------------------------------

b = DeShifr()
b.decryption([51, 24, 17, 85, 10], [159069, 56304, 151317, 756585, 23720]))   # data input
print(b.message_formation())    # receiving a decrypted message

'''



import requests

class Weather:
    
    def __init__(self, q, typed, units, appid):
        res = requests.get("http://api.openweathermap.org/data/2.5/find", 
        params={
            'q': q,
            'type': typed,
            'units': units,
            'APPID': appid
        })
        self.data = res.json()

    def get_id(self):
        return(self.data['list'][0]['id'])

    def get_request_name(self):
        return(self.data['list'][0]['name'])
    
    def get_coord_lat(self):
        return(self.data['list'][0]['coord']['lat'])

    def get_coord_lon(self):
        return(self.data['list'][0]['coord']['lon'])

    def get_country(self):
        return(self.data['list'][0]['sys']['country'])

    def get_rain(self):
        return(self.data['list'][0]['rain'])

    def get_snow(self):
        return(self.data['list'][0]['snow'])

    def get_clouds(self):
        return(self.data['list'][0]['clouds']['all'])

    def get_description(self):
        return(self.data['list'][0]['weather'][0]['description'])

    def get_temp(self):
        return(self.data['list'][0]['main']['temp'])

    def get_temp_min(self):
        return(self.data['list'][0]['main']['temp_min'])

    def get_temp_max(self):
        return(self.data['list'][0]['main']['temp_max'])
    
    def get_wind_speed(self):
        return(self.data['list'][0]['wind']['speed'])

    def get_wind_deg(self):
        return(self.data['list'][0]['wind']['deg'])

    def get_pressure(self):
        return(self.data['list'][0]['main']['pressure'])
    
    def get_humidity(self):
        return(self.data['list'][0]['main']['humidity'])

    def get_feels_like(self):
        return(self.data['list'][0]['main']['feels_like'])


import hashlib

class Hash:

    def __init__(self):
        pass

    def md5(self, obj):
        hash_object = hashlib.md5(obj.encode())
        return(hash_object.hexdigest())

    def sha1(self, obj):
        hash_object = hashlib.sha1(obj.encode())
        return(hash_object.hexdigest())
    
    def sha256(self, obj):
        hash_object = hashlib.sha256(obj.encode())
        return(hash_object.hexdigest())


from http.server import HTTPServer, CGIHTTPRequestHandler

class Web:

    def __init__(self):
        pass

    def start(self, adr):
        httpd = HTTPServer(adr, CGIHTTPRequestHandler)
        httpd.serve_forever()

    def parse(self, file):
        f = open(file, 'r').read()
        return(f)

    def heading(self):
        return("Content-type: text/html")


class Ba:
    

    def __init__(self):
        pass

    def perimeter4(self, a, b):    # находит периметр четырехугольника 
        x = (a + b) * 2
        return x

    def square4(self, a, b):     # находит площадь четырехугольника 
        x = a * b
        return x

    def sum_angles(self, ang):     # находит сумму всех углов 
        result = (ang - 2) * 180
        return result

    def square0(self, r):     # находит площадь круга 
        square = 3.141 * (r * r)
        return square

    def perimeter0(self, r):     # находит периметр круга 
        square = 9.865 * r
        return square


    def volume(self, a, b, c):  # находит объём п.п.
        res = a * b * c
        return res

    